@@ -10,9 +10,12 @@ import os
 import re
 import io
 import sys
+import atexit
+
 
 # internal modules
 import polt
+from polt.l10n import _
 from polt.utils import normalize_cmd
 
 # external modules
@@ -21,9 +24,9 @@ import xdgspec
 USER_CONFIG_FILE = os.path.join(
     xdgspec.XDGPackageDirectory("XDG_CONFIG_HOME", "polt").path, "polt.conf"
 )
-LOCAL_CONFIG_FILE = ".polt.conf"
+LOCAL_CONFIG_FILES = (".polt.conf", "polt.conf")
 
-DEFAULT_CONFIG_FILES = (USER_CONFIG_FILE, LOCAL_CONFIG_FILE)
+DEFAULT_CONFIG_FILES = (USER_CONFIG_FILE,) + LOCAL_CONFIG_FILES
 
 logger = logging.getLogger(__name__)
 
@@ -63,6 +66,9 @@ class Configuration(configparser.ConfigParser):
     Prefix for sections specifying a filter
     """
 
+    def __init__(self):
+        configparser.ConfigParser.__init__(self, interpolation=None)
+
     @property
     def source_section(self):
         """
@@ -316,7 +322,7 @@ class Configuration(configparser.ConfigParser):
         if parser_spec is None:
             raise SourceSectionError(
                 _("Section {section} does not specify a 'parser'").format(
-                    repr(section=section.name)
+                    repr(section.name)
                 )
             )
         parts = parser_spec.split(".")
@@ -371,7 +377,9 @@ class Configuration(configparser.ConfigParser):
                         shlex.split(cmd),
                         stdout=subprocess.PIPE,
                         stderr=subprocess.DEVNULL,
+                        errors="ignore",
                     )
+                    atexit.register(lambda *a, **kw: process.kill())
                 except BaseException as e:
                     raise SourceSectionError(
                         _("Could not start command {cmd}: {err}").format(
